==> haskell-data-tree-print-0.1.0.2-63-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-tree-print.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-tree-print
version:              0.1.0.2
visibility:           public
id:                   data-tree-print-0.1.0.2-JmbIUQRxBBAlR12jSze2Z
key:                  data-tree-print-0.1.0.2-JmbIUQRxBBAlR12jSze2Z
license:              BSD-3-Clause
copyright:            Copyright (C) 2016 Lennart Spitzner
maintainer:           Lennart Spitzner <hexagoxel@hexagoxel.de>
author:               Lennart Spitzner
homepage:             https://github.com/lspitzner/data-tree-print
synopsis:             Print Data instances as a nested tree
description:
    Provides functionality similar to that of the `Show` class: Taking some
    arbitrary value and returning a String.

    * Output is not intended to be valid haskell.

    * Requires a `Data.Data.Data` instance instead of a `Text.Show` one.

    * Output, if large, is often easier to parse than `show` output
    due to the formatting as a nested tree.

    * The user can adapt the behaviour at runtime using custom layouting
    expressed via syb-style extension.

category:             Pretty Printer
abi:                  24ca7ee4db535251444da827d00060db
exposed:              True
exposed-modules:      DataTreePrint
import-dirs:          /usr/lib/ghc-9.0.1/site-local/data-tree-print-0.1.0.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/data-tree-print-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/data-tree-print-0.1.0.2
hs-libraries:         HSdata-tree-print-0.1.0.2-JmbIUQRxBBAlR12jSze2Z
depends:
    base-4.15.0.0 pretty-1.1.3.6 syb-0.7.2.1-JG4kH6P0JxMKeIFdjWhhC8

haddock-interfaces:
    /usr/share/doc/haskell-data-tree-print/html/data-tree-print.haddock

haddock-html:         /usr/share/doc/haskell-data-tree-print/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-tree-print-0.1.0.2-64-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-tree-print.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-tree-print
version:              0.1.0.2
visibility:           public
id:                   data-tree-print-0.1.0.2-G3cwNJ4u2eI2v6buUWWT1w
key:                  data-tree-print-0.1.0.2-G3cwNJ4u2eI2v6buUWWT1w
license:              BSD-3-Clause
copyright:            Copyright (C) 2016 Lennart Spitzner
maintainer:           Lennart Spitzner <hexagoxel@hexagoxel.de>
author:               Lennart Spitzner
homepage:             https://github.com/lspitzner/data-tree-print
synopsis:             Print Data instances as a nested tree
description:
    Provides functionality similar to that of the `Show` class: Taking some
    arbitrary value and returning a String.

    * Output is not intended to be valid haskell.

    * Requires a `Data.Data.Data` instance instead of a `Text.Show` one.

    * Output, if large, is often easier to parse than `show` output
    due to the formatting as a nested tree.

    * The user can adapt the behaviour at runtime using custom layouting
    expressed via syb-style extension.

category:             Pretty Printer
abi:                  53df1766820d37995cab86f651ea03e6
exposed:              True
exposed-modules:      DataTreePrint
import-dirs:          /usr/lib/ghc-9.0.1/site-local/data-tree-print-0.1.0.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/data-tree-print-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/data-tree-print-0.1.0.2
hs-libraries:         HSdata-tree-print-0.1.0.2-G3cwNJ4u2eI2v6buUWWT1w
depends:
    base-4.15.0.0 pretty-1.1.3.6 syb-0.7.2.1-8W5S2ZI4XGsCYkkZdVEejv

haddock-interfaces:
    /usr/share/doc/haskell-data-tree-print/html/data-tree-print.haddock

haddock-html:         /usr/share/doc/haskell-data-tree-print/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
